summaryrefslogtreecommitdiffstats
path: root/ffi/include
diff options
context:
space:
mode:
authorNeal H. Walfield <neal@pep.foundation>2018-12-17 12:48:07 +0100
committerNeal H. Walfield <neal@pep.foundation>2018-12-17 15:45:59 +0100
commit3366d09c94c88bb8366ed470e49ff841f336b894 (patch)
tree57e4e6dc28cc9457cf57555e941753812d03c34f /ffi/include
parent05e1b5dc9d189e3129f8da2c6beacb014f3fd698 (diff)
openpgp: Change KeyIter to also return the RevocationStatus.
- A Key's revocation status is a property of its binding, but the binding is not exposed by KeyIter. Expose it.
Diffstat (limited to 'ffi/include')
-rw-r--r--ffi/include/sequoia/openpgp.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/ffi/include/sequoia/openpgp.h b/ffi/include/sequoia/openpgp.h
index 0e0439f8..765ff1a6 100644
--- a/ffi/include/sequoia/openpgp.h
+++ b/ffi/include/sequoia/openpgp.h
@@ -610,16 +610,19 @@ void sq_user_id_binding_iter_free (sq_user_id_binding_iter_t iter);
typedef struct sq_tpk_key_iter *sq_tpk_key_iter_t;
/*/
-/// Returns a reference to the next element in the iterator. Returns
-/// NULL if there are no more elements.
+/// Returns the next key. Returns NULL if there are no more elements.
///
/// If signature is not NULL, stores a reference to the key's most
/// recent self-signature, if any. (Note: subkeys always have
/// signatures, but a primary key may not have a direct signature, and
/// there might not be any user ids.)
/*/
sq_p_key_t sq_tpk_key_iter_next (sq_tpk_key_iter_t iter,
- sq_packet_t *signature);
+ sq_signature_t *signature,
+ sq_revocation_status_t *rev);
/// Frees an sq_tpk_key_iter_t.
void sq_tpk_key_iter_free (sq_tpk_key_iter_t iter);
@@ -610,16 +610,19 @@ void sq_user_id_binding_iter_free (sq_user_id_binding_iter_t iter);
///
-/// If signature is not NULL, stores a reference to the key's most
-/// recent self-signature, if any. (Note: subkeys always have
-/// signatures, but a primary key may not have a direct signature, and
-/// there might not be any user ids.)
+/// If sigo is not NULL, stores the current self-signature (if any) in
+/// *sigo. (Note: subkeys always have signatures, but a primary key
+/// may not have a direct signature, and there might not be any user
+/// ids.)
+///
+/// If rso is not NULL, this stores the key's revocation status in
+/// *rso.
/*/
sq_p_key_t sq_tpk_key_iter_next (sq_tpk_key_iter_t iter,